@@ -1,4 +1,4 @@
-#define DELAY 1 /* Delay between refreshes (in seconds) */
+#include "apm.h"
 
 typedef struct {
 	Pixmap pixmap;
@@ -6,19 +6,6 @@ typedef struct {
   	XpmAttributes attributes;
 } XpmIcon;
 
-typedef struct {
-	const char driver_version[10];
-	int apm_version_major;
-   	int apm_version_minor;
-   	int apm_flags;
-   	int ac_line_status;
-   	int battery_status;
-   	int battery_flags;
-   	int battery_percentage;
-   	int battery_time;
-   	int using_minutes;
-} apm_info;
-
 typedef struct image_info_type {
   	const char* filename;
   	const int width;
@@ -28,16 +15,12 @@ typedef struct image_info_type {
   	const int charwidth;
 } image_info_type;
 
-#ifndef APM_32_BIT_SUPPORT
-#define APM_32_BIT_SUPPORT      0x0002
-#endif
-
 /* Assign reference numbers to all images that are loaded. */
 #define SMALLFONT 0
 #define BIGFONT 1
 #define BATTERY_HIGH 2
-#define BATTERY_MEDIUM 3
-#define BATTERY_LOW 4
+#define BATTERY_LOW 3
+#define BATTERY_CRITICAL 4
 #define BATTERY_NONE 5
 #define BATTERY_BLINK 6
 #define UNPLUGGED 7
